"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.notify = exports.TemplateChannel = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixPingNotificationsV3Notification = __importStar(require("./ping-notifications-v3-notification-notifications-v-3.http.js"));
var TemplateChannel;
(function (TemplateChannel) {
    TemplateChannel["WEB_FEED"] = "WEB_FEED";
    TemplateChannel["MOBILE_FEED"] = "MOBILE_FEED";
    TemplateChannel["MOBILE_PUSH"] = "MOBILE_PUSH";
    TemplateChannel["BROWSER"] = "BROWSER";
    TemplateChannel["SMS"] = "SMS";
    TemplateChannel["EMAIL"] = "EMAIL";
    TemplateChannel["KAFKA"] = "KAFKA";
    TemplateChannel["VOICE"] = "VOICE";
})(TemplateChannel || (exports.TemplateChannel = TemplateChannel = {}));
/**
 * Sends notifications based on the template and dynamic values provided.
 *
 * > **Note**: An app can call this method up to 100,000 times per month for each site.
 *
 * When you create a notification template ([SDK](https://dev.wix.com/docs/sdk/backend-modules/notifications/notifications-v3/create-a-notification-template) | [REST](https://dev.wix.com/docs/rest/business-management/notifications/notifications/creating-a-notification-template)), you are provided with a notification template ID. Call the Notify method with this ID as `notificationTemplateID` to trigger notifications based on that template.
 *
 * If the notification template contains placeholders for dynamic values, provide those values as key-value pairs in the `dynamicValues` array. The values you specify are incorporated in the notifications sent out.
 * @param notificationTemplateId - Notification template ID. A notification template specifies the text and recipients for notifications.
 * To obtain a notification template ID, create a notification template in your [app's dashboard](https://dev.wix.com/docs/build-apps/develop-your-app/app-dashboard-setup/about-the-app-dashboard).
 * @public
 * @requiredField notificationTemplateId
 * @permissionId NOTIFICATIONS.SEND_NOTIFICATION
 * @permissionScope Manage Notifications
 * @permissionScopeId SCOPE.DC-NOTIFICATIONS.MANAGE-NOTIFICATIONS
 * @applicableIdentity APP
 * @fqn com.wixpress.ping.hub.api.v3.NotificationsServiceV3.Notify
 */
async function notify(notificationTemplateId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        notificationTemplateId: notificationTemplateId,
        dynamicValues: options?.dynamicValues,
    });
    const reqOpts = ambassadorWixPingNotificationsV3Notification.notify(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                notificationTemplateId: '$[0]',
                dynamicValues: '$[1].dynamicValues',
            },
            singleArgumentUnchanged: false,
        }, ['notificationTemplateId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.notify = notify;
//# sourceMappingURL=ping-notifications-v3-notification-notifications-v-3.universal.js.map