"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.notify = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressPingHubApiV3NotificationsServiceV3Url(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/notifications-hub-server',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/ping/hub',
                destPath: '',
            },
            {
                srcPath: '/_api/ping/notifications',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/ping/hub',
                destPath: '',
            },
            {
                srcPath: '/_api/ping/notifications',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/notifications/v3/notify',
                destPath: '/v3/notify',
            },
        ],
    };
    return (0, rest_modules_1.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_notifications_notifications-v-3';
/**
 * Sends notifications based on the template and dynamic values provided.
 *
 * > **Note**: An app can call this method up to 100,000 times per month for each site.
 *
 * When you create a notification template ([SDK](https://dev.wix.com/docs/sdk/backend-modules/notifications/notifications-v3/create-a-notification-template) | [REST](https://dev.wix.com/docs/rest/business-management/notifications/notifications/creating-a-notification-template)), you are provided with a notification template ID. Call the Notify method with this ID as `notificationTemplateID` to trigger notifications based on that template.
 *
 * If the notification template contains placeholders for dynamic values, provide those values as key-value pairs in the `dynamicValues` array. The values you specify are incorporated in the notifications sent out.
 */
function notify(payload) {
    function __notify({ host }) {
        const metadata = {
            entityFqdn: 'wix.ping.notifications.v3.notification',
            method: 'POST',
            methodFqn: 'com.wixpress.ping.hub.api.v3.NotificationsServiceV3.Notify',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressPingHubApiV3NotificationsServiceV3Url({
                protoPath: '/v3/notify',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __notify;
}
exports.notify = notify;
//# sourceMappingURL=ping-notifications-v3-notification-notifications-v-3.http.js.map