import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixPingNotificationsV3Notification from './ping-notifications-v3-notification-notifications-v-3.http.js';
export var TemplateChannel;
(function (TemplateChannel) {
    TemplateChannel["WEB_FEED"] = "WEB_FEED";
    TemplateChannel["MOBILE_FEED"] = "MOBILE_FEED";
    TemplateChannel["MOBILE_PUSH"] = "MOBILE_PUSH";
    TemplateChannel["BROWSER"] = "BROWSER";
    TemplateChannel["SMS"] = "SMS";
    TemplateChannel["EMAIL"] = "EMAIL";
    TemplateChannel["KAFKA"] = "KAFKA";
    TemplateChannel["VOICE"] = "VOICE";
})(TemplateChannel || (TemplateChannel = {}));
/**
 * Sends notifications based on the template and dynamic values provided.
 *
 * > **Note**: An app can call this method up to 100,000 times per month for each site.
 *
 * When you create a notification template ([SDK](https://dev.wix.com/docs/sdk/backend-modules/notifications/notifications-v3/create-a-notification-template) | [REST](https://dev.wix.com/docs/rest/business-management/notifications/notifications/creating-a-notification-template)), you are provided with a notification template ID. Call the Notify method with this ID as `notificationTemplateID` to trigger notifications based on that template.
 *
 * If the notification template contains placeholders for dynamic values, provide those values as key-value pairs in the `dynamicValues` array. The values you specify are incorporated in the notifications sent out.
 * @param notificationTemplateId - Notification template ID. A notification template specifies the text and recipients for notifications.
 * To obtain a notification template ID, create a notification template in your [app's dashboard](https://dev.wix.com/docs/build-apps/develop-your-app/app-dashboard-setup/about-the-app-dashboard).
 * @public
 * @requiredField notificationTemplateId
 * @permissionId NOTIFICATIONS.SEND_NOTIFICATION
 * @permissionScope Manage Notifications
 * @permissionScopeId SCOPE.DC-NOTIFICATIONS.MANAGE-NOTIFICATIONS
 * @applicableIdentity APP
 * @fqn com.wixpress.ping.hub.api.v3.NotificationsServiceV3.Notify
 */
export async function notify(notificationTemplateId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        notificationTemplateId: notificationTemplateId,
        dynamicValues: options?.dynamicValues,
    });
    const reqOpts = ambassadorWixPingNotificationsV3Notification.notify(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                notificationTemplateId: '$[0]',
                dynamicValues: '$[1].dynamicValues',
            },
            singleArgumentUnchanged: false,
        }, ['notificationTemplateId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=ping-notifications-v3-notification-notifications-v-3.universal.js.map